@@ -19,6 +19,7 @@ from enum import IntEnum
 from bcc import BPF
 from prettytable import PrettyTable
 
+from pg_lock_tracer import __version__
 from pg_lock_tracer.oid_resolver import OIDResolver
 from pg_lock_tracer.helper import PostgreSQLLockHelper, BPFHelper
 
@@ -44,7 +45,7 @@ pg_lock_tracer -x /home/jan/postgresql-sandbox/bin/REL_15_1_DEBUG/bin/postgres -
 pg_lock_tracer -x /home/jan/postgresql-sandbox/bin/REL_15_1_DEBUG/bin/postgres -p 1234 -s DEADLOCK
 
 # Print stacktrace for locks and deadlocks
-pg_lock_tracer -x /home/jan/postgresql-sandbox/bin/REL_15_1_DEBUG/bin/postgres -p 1234 -s LOCK, DEADLOCK
+pg_lock_tracer -x /home/jan/postgresql-sandbox/bin/REL_15_1_DEBUG/bin/postgres -p 1234 -s LOCK DEADLOCK
 
 # Trace only Transaction and Query related events
 pg_lock_tracer -x /home/jan/postgresql-sandbox/bin/REL_15_1_DEBUG/bin/postgres -p 1234 -t TRANSACTION QUERY
@@ -74,6 +75,12 @@ parser = argparse.ArgumentParser(
     formatter_class=argparse.RawDescriptionHelpFormatter,
     epilog=EXAMPLES,
 )
+parser.add_argument(
+    "-V",
+    "--version",
+    action="version",
+    version=f"{parser.prog} ({__version__})",
+)
 parser.add_argument("-v", "--verbose", action="store_true", help="be verbose")
 parser.add_argument(
     "-j", "--json", action="store_true", help="generate output as JSON data"
